import Joi from 'joi';
import { AccessInfo } from '../auth';
declare type ModelBrowseArgs = {
    pagination?: ModelBrowsePagination;
    select?: any;
    where?: any;
    orderBy?: any;
    distinct?: any;
    take?: number;
    skip?: number;
    options?: ModelBrowseOptions;
};
export declare type ModelErrorHandler = (error: TypeError, params: ModelMiddlewareParams, accessInfo: AccessInfo) => never;
export declare const OmitCreateInput: {
    createdBy: number;
    createdByName: string;
};
export declare const OmitUpdateInput: {
    updatedBy: number;
    updatedByName: string;
};
export declare type ModelMiddlewareParams = {
    model?: string;
    action: string;
    args: any;
    dataPath: string[];
    runInTransaction: boolean;
};
export declare type ModelBatchPayload = {
    count: number;
};
export interface ModelBrowsePagination {
    pageSize?: number;
    page?: number;
}
export declare type ModelBrowseOptions = {
    speedMode?: boolean;
};
export declare type ModelBrowseReturn<T> = {
    items: T[];
    properties: ModelBrowsePagination | {
        count: number;
    };
};
export declare type ModelSchemas = {
    schemaCreateInput?: Joi.ObjectSchema;
    schemaUpdateInput?: Joi.ObjectSchema;
};
export declare class ModelMiddleware<T, PrismaClient, ModelClient, CustomBrowseArgs extends ModelBrowseArgs> {
    readonly client: PrismaClient;
    readonly model: ModelClient;
    protected readonly schemas: ModelSchemas;
    protected readonly accessInfo: AccessInfo;
    constructor(client: PrismaClient, model: string, accessInfo: AccessInfo, errorHandler?: ModelErrorHandler, schemas?: ModelSchemas);
    private packCreateArgs;
    private packUpdateArgs;
    private packUpsertArgs;
    browse(params: CustomBrowseArgs): Promise<ModelBrowseReturn<T>>;
}
export {};
